tests package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tests.management

Submodules
----------

tests.settings module
---------------------

.. automodule:: tests.settings
   :members:
   :show-inheritance:
   :undoc-members:

tests.test\_admin module
------------------------

.. automodule:: tests.test_admin
   :members:
   :show-inheritance:
   :undoc-members:

tests.test\_models module
-------------------------

.. automodule:: tests.test_models
   :members:
   :show-inheritance:
   :undoc-members:

tests.test\_views module
------------------------

.. automodule:: tests.test_views
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tests
   :members:
   :show-inheritance:
   :undoc-members:
